@@ -23,8 +23,6 @@
 
 #include <config.h>
 #include <string.h>
-#include <glib/gdataset.h>
-#include <glib/gquark.h>
 
 #include "htmlclue.h"
 #include "htmlclueflow.h"
@@ -47,7 +45,6 @@
 #include "htmlrule.h"
 #include "htmltype.h"
 #include "htmlsettings.h"
-#include "htmlutils.h"
 
 #include "gtkhtmldebug.h"
 
@@ -74,7 +71,7 @@ destroy (HTMLObject *self)
 
 	g_free (self->id);
 	self->id = NULL;
-	
+
 	if (self->redraw_pending) {
 		self->free_pending = TRUE;
 	} else {
@@ -248,7 +245,7 @@ calc_preferred_width (HTMLObject *o, HTMLPainter *painter)
 	html_object_calc_size (o, painter, NULL);
 	return o->width;
 }
-	
+
 static void
 set_max_width (HTMLObject *o, HTMLPainter *painter, gint max_width)
 {
@@ -322,7 +319,7 @@ get_bg_color (HTMLObject *o,
 	      HTMLPainter *p)
 {
 	if (o->parent)
-		return html_object_get_bg_color (o->parent, p);	
+		return html_object_get_bg_color (o->parent, p);
 
 	if (p->widget && GTK_IS_HTML (p->widget)) {
 		HTMLEngine *e = html_object_engine (o, GTK_HTML (p->widget)->engine);
@@ -347,7 +344,7 @@ check_point (HTMLObject *self,
 			*offset_return = 0;
 		return self;
 	}
-    
+
 	return NULL;
 }
 
@@ -396,7 +393,7 @@ relayout (HTMLObject *self,
 
 		return FALSE;
 	}
-	
+
 	gtk_html_debug_log (engine->widget, "relayout: %s %p changed.\n",
 			    html_type_name (HTML_OBJECT_TYPE (self)), self);
 
@@ -873,7 +870,7 @@ HTMLObject *
 html_object_new (HTMLObject *parent)
 {
 	HTMLObject *o;
-	
+
 	o = g_new0 (HTMLObject, 1);
 	html_object_init (o, &html_object_class);
 
@@ -951,14 +948,14 @@ html_object_set_parent (HTMLObject *o, HTMLObject *parent)
 
 
 static void
-frame_offset (HTMLObject *o, 
+frame_offset (HTMLObject *o,
 	      gint *x_return, gint *y_return)
 {
 	if (html_object_is_frame (o)) {
 		HTMLEngine *e = html_object_get_engine (o, NULL);
 		*x_return -= e->x_offset;
 		*y_return -= e->y_offset;
-	} 
+	}
 }
 
 void
@@ -971,13 +968,13 @@ html_object_calc_abs_position (HTMLObject *o,
 
 	*x_return = o->x;
 	*y_return = o->y;
-	
+
 	frame_offset (o, x_return, y_return);
 
 	for (p = o->parent; p != NULL; p = p->parent) {
 		*x_return += p->x;
 		*y_return += p->y - p->ascent;
-		
+
 		frame_offset (p, x_return, y_return);
 	}
 }
@@ -991,13 +988,13 @@ html_object_calc_abs_position_in_frame (HTMLObject *o, int *x_return, int *y_ret
 
 	*x_return = o->x;
 	*y_return = o->y;
-	
+
 	frame_offset (o, x_return, y_return);
 
 	for (p = o->parent; p != NULL && !html_object_is_frame (p); p = p->parent) {
 		*x_return += p->x;
 		*y_return += p->y - p->ascent;
-		
+
 		frame_offset (p, x_return, y_return);
 	}
 }
@@ -1067,7 +1064,7 @@ html_object_is_transparent (HTMLObject *self)
 HTMLFitType
 html_object_fit_line (HTMLObject *o,
 		      HTMLPainter *painter,
-		      gboolean start_of_line, 
+		      gboolean start_of_line,
 		      gboolean first_run,
 		      gboolean next_to_floating,
 		      gint width_left)
@@ -1152,11 +1149,11 @@ html_object_calc_preferred_width (HTMLObject *o,
 
 #if 0
 gint
-html_object_get_uris (HTMLObject *o, char **link, char **target, char **src) 
+html_object_get_uris (HTMLObject *o, char **link, char **target, char **src)
 {
 	return TRUE;
 }
-#endif 
+#endif
 
 const gchar *
 html_object_get_url (HTMLObject *o, gint offset)
@@ -1174,16 +1171,11 @@ gchar *
 html_object_get_complete_url (HTMLObject *o, gint offset)
 {
 	const gchar *url, *target;
-	gchar *url2, *url3;
 
 	url = html_object_get_url (o, offset);
 	target = html_object_get_target (o, offset);
-	url2 = url || target ? g_strconcat (url ? url : "#", url ? (target && *target ? "#" : NULL) : target,
-					    url ? target : NULL, NULL) : NULL;
-	url3 = html_utils_maybe_unescape_amp (url2);
-	g_free (url2);
-
-	return url3;
+	return url || target ? g_strconcat (url ? url : "#", url ? (target && *target ? "#" : NULL) : target,
+					      url ? target : NULL, NULL) : NULL;
 }
 
 const gchar *
@@ -1859,8 +1851,11 @@ object_save_data (GQuark key_id, gpointer data, gpointer user_data)
 	/* printf ("object %s %s\n", g_quark_to_string (key_id), str); */
 	if (!str) {
 		/* printf ("save %s %s -> %s\n", state->save_data_class_name, g_quark_to_string (key_id), (gchar *) data); */
-		html_engine_save_output_string (state, "<!--+GtkHTML:<DATA class=\"%s\" key=\"%s\" value=\"%s\">-->",
-						state->save_data_class_name, g_quark_to_string (key_id), (char *) data);
+		html_engine_save_delims_and_vals (state,
+				"<!--+GtkHTML:<DATA class=\"", state->save_data_class_name,
+				"\" key=\"", g_quark_to_string (key_id),
+				"\" value=\"", (char *) data,
+				"\">-->", NULL);
 		html_engine_set_class_data (state->engine, state->save_data_class_name, g_quark_to_string (key_id), data);
 	}
 }
@@ -1875,13 +1870,18 @@ handle_object_data (gpointer key, gpointer value, gpointer data)
 	/* printf ("handle: %s %s %s %s\n", state->save_data_class_name, key, value, str); */
 	if (!str) {
 		/* printf ("clear\n"); */
-		html_engine_save_output_string (state, "<!--+GtkHTML:<DATA class=\"%s\" clear=\"%s\">-->",
-						state->save_data_class_name, (char *) key);
+		html_engine_save_delims_and_vals (state,
+				"<!--+GtkHTML:<DATA class=\"", state->save_data_class_name,
+				"\" clear=\"", (char *) key,
+				"\">-->", NULL);
 		state->data_to_remove = g_slist_prepend (state->data_to_remove, key);
 	} else if (strcmp (value, str)) {
 		/* printf ("change\n"); */
-		html_engine_save_output_string (state, "<!--+GtkHTML:<DATA class=\"%s\" key=\"%s\" value=\"%s\">-->",
-						state->save_data_class_name, (char *) key, str);
+		html_engine_save_delims_and_vals (state,
+				"<!--+GtkHTML:<DATA class=\"", state->save_data_class_name,
+				"\" key=\"", (char *) key,
+				"\" value=\"", str,
+				"\">-->", NULL);
 		html_engine_set_class_data (state->engine, state->save_data_class_name, key, value);
 	}
 }
